#ifndef KYSDK_APIAUTHSEC_H
#define KYSDK_APIAUTHSEC_H

#include <sys/types.h>

#ifdef __cplusplus
extern "C" 
{
#endif

#define KYSEC_INTERFACE_AUTHORIZATION_ALLOW       (1000)
#define KYSEC_INTERFACE_AUTHORIZATION_DENY        (1001)

#define KYSEC_INTERFACE_AUTHORIZATION_SUCCESS     (0)
#define KYSEC_INTERFACE_AUTHORIZATION_ENTRY_EXIST (-5020)
#define KYSEC_INTERFACE_AUTHORIZATION_NOENTRY     (-5021)
#define KYSEC_INTERFACE_AUTHORIZATION_NOPERM      (-5001)
#define KYSEC_INTERFACE_AUTHORIZATION_DBERR       (-5002)
#define KYSEC_INTERFACE_AUTHORIZATION_SYSERR      (-5010)

enum KYSEC_INTERFACE_AUTHORIZATION_TYPE {
    KYSEC_INTERFACE_AUTHORIZATION_ALL = 0,
    KYSEC_INTERFACE_AUTHORIZATION_START = 1000,
    KYSEC_INTERFACE_AUTHORIZATION_DEVCTL = KYSEC_INTERFACE_AUTHORIZATION_START,   //外设管控
    KYSEC_INTERFACE_AUTHORIZATION_FIREWALL,                                  //防火墙
    KYSEC_INTERFACE_AUTHORIZATION_PPRO,                                      //进程防护
    KYSEC_INTERFACE_AUTHORIZATION_FPRO,                                      //文件防护
    KYSEC_INTERFACE_AUTHORIZATION_KMODPRO,                                   //内核模块防卸载
    KYSEC_INTERFACE_AUTHORIZATION_NETCTL,                                    //网络管控
    KYSEC_INTERFACE_AUTHORIZATION_PKGCTL,                                    //安装包管控
    KYSEC_INTERFACE_AUTHORIZATION_UNDEF
};

/// @brief 验证当前进程是否有权限调用对应接口
/// @param type 接口类型，参见KYSEC_INTERFACE_AUTHORIZATION_TYPE
/// @param perm 权限返回值
/// @return 校验结果
extern int kysec_interface_check_app(int type, int *perm);

/// @brief 通过pid验证进程是否有权限调用对应接口，供dbus的服务端做验证
/// @param pid 进程pid
/// @param type 接口类型，参见KYSEC_INTERFACE_AUTHORIZATION_TYPE
/// @param perm 权限返回值
/// @return 校验结果
extern int kysec_interface_check_pid(pid_t pid, int type, int *perm);

#ifdef __cplusplus
}
#endif

#endif